@@ -1,6 +1,8 @@
 
 from junopy.utils.juno import *
 
+import hmac
+import hashlib
 
 def Banks():
     data = Get("/data/banks")
@@ -17,3 +19,8 @@ def BusinessAreas():
 def PublicKey(resourceToken=None):
     data = Get("/credentials/public-key", {'resourceToken': resourceToken})
     return data
+
+def IsValidWebhook(x_signature:str, body:bytes, secret:str):
+    secret = secret.encode('utf-8')
+    digest = hmac.HMAC(secret, body, hashlib.sha256).hexdigest()
+    return digest == x_signature
